## Make sure you have python3 and pip installed

## To install
# Linux
python3 -m pip install --user pipx; python3 -m pip install --user pipx

# macOS
brew install pipx; pipx ensurepath

## How to use
# Linux and macOS
TeXlinter <your .tex document>